%define shortver %(echo %{version}|cut -d. -f1,2)

%global fontdir %{_datadir}/fonts/mscore

Summary:        Linux MusE Score Typesetter
Name:           mscore
Version:        3.5.2
Release:        %mkrel 3
# (Fedora) rtf2html is LGPLv2+
# paper4.png paper5.png are LGPLv3
# the rest is GPLv2
# Soundfont is MIT
# Bravura and gootville are OFL
License:        GPLv2 and LGPLv2+ and LGPLv3 and CC-BY and MIT and OFL
Url:            https://musescore.org
Group:          Publishing
Source0:        https://github.com/musescore/MuseScore/archive/v%{version}/MuseScore-%{version}.tar.gz

# For mime types
Source1:        %{name}.xml
# Add metainfo file for font to show in gnome-software
Source2:        %{name}.metainfo.xml

# Use Fedora's default soundfont instead of the removed one:
Patch0:         mscore-3.2.3-use-default-soundfont.patch
# We don't build the common files (font files, wallpapers, demo song, instrument
# list) into the binary executable to reduce its size. This is also useful to
# inform the users about the existence of different choices for common files.
# The font files need to be separated due to the font packaging guidelines.
Patch1:         mscore-3.5.1-separate-commonfiles.patch
# Fix desktop file. The Version= field is for the Desktop File Specification version
# not the version of MuseScore
Patch3:         mscore-2.3.2-fix-desktop-file.patch
# Use CXXFLAGS for precompiled header
Patch4:         musescore-2.0.1-fix-flags-for-precompiled-header.patch
# link with system lame
Patch5:         mscore-3.5.0-lame-link.patch
# revision number (in mscore/revision.h) is incorrect in the assets automatically
# generated by GitHub
Patch6:         mscore-3.5.2-fix-revision-number.patch
# Fix some glitches in the OMR code
Patch7:         mscore-3.5.0-omr.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  qttools5-assistant
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  perl(Pod::Usage)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(poppler-qt5)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5QuickWidgets)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  lame-devel
BuildRequires:  portmidi-devel
BuildRequires:  porttime-devel
BuildRequires:  qtsingleapplication-qt5-devel

Requires:       qtquickcontrols2
Requires:       qtquickcontrols5
Requires:       qtwebengine5
Requires:       %{name}-fonts = %{version}-%{release}
Requires:       soundfont2-default
Provides:       musescore = %{version}-%{release}

# Doxygen documentation is huge and it is for musescore development only.
# Hence we don't build it for now. Otherwise it needs:
# BuildRequires: graphviz doxygen texlive-latex texlive-dvips

%description
MuseScore stands for Linux MusE Score Typesetter.

Features:
 - WYSIWYG design, notes are entered on a "virtual notepaper"
 - TrueType font(s) for printing & display allows for high quality
   scaling to all sizes
 - easy & fast note entry
 - many editing functions
 - MusicXML import/export
 - Midi (SMF) import/export
 - MuseData import
 - Midi input for note entry
 - integrated sequencer and software synthesizer to
   play the score
 - print or create pdf files

%package doc
Summary:        MuseScore documentation
Group:          Development/Other
License:        CC-BY
Requires:       %{name} >= %{version}-%{release}
BuildArch:      noarch

%description doc
MuseScore is a free cross platform WYSIWYG music notation program.

This package contains the user manual of MuseScore in different languages.

%package fonts
Summary:        MuseScore fonts
Group:          Publishing
License:        GPL+ with exceptions and OFL
BuildArch:      noarch
BuildRequires:  fontforge
BuildRequires:  texlive
BuildRequires:  texlive-texmf
BuildRequires:  t1utils


%description fonts
MuseScore is a free cross platform WYSIWYG music notation program.

This package contains the musical notation fonts for use of MuseScore.

%prep
%setup -q -n MuseScore-%{version}
%autopatch -p1

# Remove bundled stuff
sed -i -e 's|#include "singleapp/src/QtSingleApplication"|#include <QtSolutions/QtSingleApplication>|' mscore/musescore.h
rm -vrf thirdparty/singleapp
rm -vrf thirdparty/freetype
rm -vrf thirdparty/poppler

rm demos/All_Dudes.mscz demos/Triumph.mscz

%build
# Build the actual program
%cmake \
	-DMUSESCORE_BUILD_CONFIG=release \
	-DCMAKE_CXX_FLAGS_RELWITHDEBINFO:STRING="-DNDEBUG -DQT_NO_DEBUG" \
	-DUSE_PATH_WITH_EXPLICIT_QT_VERSION=ON \
	-DUSE_SYSTEM_QTSINGLEAPPLICATION=ON \
	-DUSE_SYSTEM_FREETYPE=ON \
	-DUSE_SYSTEM_POPPLER=ON \
	-DOMR=ON \
	-DDOWNLOAD_SOUNDFONT=OFF \
	-DBUILD_WEBENGINE=ON \
	-DBUILD_LAME=ON \
	-DBUILD_CRASH_REPORTER=OFF

%make_build -C build PREFIX=%{_prefix} lrelease
%make_build -C build PREFIX=%{_prefix} manpages
%make_build -C build PREFIX=%{_prefix} VERBOSE=1
%__make -C build/rdoc referenceDocumentation PREFIX=%{_prefix}

%install
echo %{shortver}
%make_install -C build PREFIX=%{_prefix}
%make_install -C build/rdoc PREFIX=%{_prefix}

# Install fonts
mkdir -p %{buildroot}%{fontdir}
mkdir -p %{buildroot}%{fontdir}/bravura
mkdir -p %{buildroot}%{fontdir}/campania
mkdir -p %{buildroot}%{fontdir}/gootville
mkdir -p %{buildroot}%{fontdir}/musejazz
install -pm 644 fonts/*.ttf %{buildroot}%{fontdir}
install -pm 644 fonts/bravura/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/bravura/*.json %{buildroot}%{fontdir}/bravura
install -pm 644 fonts/campania/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/gootville/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/gootville/*.json %{buildroot}%{fontdir}/gootville/
install -pm 644 fonts/mscore/*.ttf %{buildroot}%{fontdir}
install -pm 644 fonts/mscore/*.json %{buildroot}%{fontdir}
install -pm 644 fonts/musejazz/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/musejazz/*.json %{buildroot}%{fontdir}/musejazz/
install -pm 644 fonts/*.xml %{buildroot}%{fontdir}

# mscz and mscx
mkdir -p %{buildroot}%{_datadir}/%{name}-%{shortver}/demos/
install -p share/templates/*.mscz %{buildroot}%{_datadir}/%{name}-%{shortver}/demos/
install -p share/templates/*.mscx %{buildroot}%{_datadir}/%{name}-%{shortver}/demos/

pushd %{buildroot}%{fontdir}
cd bravura
ln -s ../Bravura.otf .
ln -s ../BravuraText.otf .
cd ../campania
ln -s ../Campania.otf .
cd ../gootville
ln -s ../Gootville.otf .
ln -s ../GootvilleText.otf .
cd ../musejazz
ln -s ../MuseJazz.otf .
ln -s ../MuseJazzText.otf .
cd ..
popd

# Mime type
mkdir -p %{buildroot}%{_datadir}/mime/packages
install -pm 644 %{SOURCE1} %{buildroot}%{_datadir}/mime/packages/

# Desktop file
desktop-file-install \
   --dir=%{buildroot}%{_datadir}/applications \
   --add-category="X-Notation" \
   --remove-category="Sequencer" \
   --remove-category="AudioVideoEditing" \
   --add-mime-type="audio/midi" \
   --add-mime-type="text/x-lilypond" \
   --add-mime-type="application/xml" \
   %{buildroot}%{_datadir}/applications/%{name}.desktop

# Move images to the freedesktop location
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/64x64/mimetypes/
cp -a mscore/data/mscore.png \
   %{buildroot}%{_datadir}/icons/hicolor/64x64/mimetypes/application-x-musescore.png

# There are many doc files spread around the tarball. Let's collect them
mkdir -p docs
rm -rf docs/*
cp -a thirdparty/rtf2html/ChangeLog        docs/ChangeLog.rtf2html
cp -a thirdparty/rtf2html/COPYING.LESSER   docs/COPYING.LESSER.rtf2html
cp -a thirdparty/rtf2html/README           docs/README.rtf2html
cp -a thirdparty/rtf2html/README.mscore    docs/README.mscore.rtf2html
cp -a thirdparty/rtf2html/README.ru        docs/README.ru.rtf2html
cp -a share/wallpaper/COPYRIGHT            docs/COPYING.wallpaper
cp -a fonts/bravura/OFL.txt                docs/COPYING.OFL
cp -a share/sound/FluidR3Mono_License.md  docs/COPYING.FluidR3Mono

# Add AppStream metadata for fonts
install -Dm 0644 -p %{SOURCE2} \
  %{buildroot}%{_datadir}/appdata/%{name}.metainfo.xml

# Install soundfont
install -Dm 0644 -p share/sound/FluidR3Mono_GM.sf3 \
  %{buildroot}%{_datadir}/soundfonts/FluidR3Mono_GM.sf3

%files
%doc README* docs/ChangeLog* docs/README*
%license docs/COPYING*
%{_bindir}/%{name}
%{_bindir}/musescore
%{_datadir}/%{name}-%{shortver}/
%exclude %{_datadir}/%{name}-%{shortver}/manual/
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/mime/packages/musescore.xml
%{_mandir}/man1/*.1*
%{_datadir}/soundfonts/FluidR3Mono_GM.sf3
%{_metainfodir}/org.musescore.MuseScore.appdata.xml

%files doc
%doc %{_datadir}/%{name}-%{shortver}/manual/

%files fonts
%{_datadir}/fonts/mscore/
%{_datadir}/appdata/%{name}.metainfo.xml


%changelog
* Thu Jan 28 2021 daviddavid <daviddavid> 3.5.2-3.mga8
+ Revision: 1673847
- ensure a release build, not a dev build

* Tue Jan 26 2021 daviddavid <daviddavid> 3.5.2-2.mga8
+ Revision: 1673376
- Rebuild for new Qt5

* Tue Nov 03 2020 akien <akien> 3.5.2-1.mga8
+ Revision: 1642220
- Version 3.5.2

* Wed Oct 07 2020 daviddavid <daviddavid> 3.5.1-1.mga8
+ Revision: 1632526
- new version: 3.5.1

* Wed Aug 12 2020 daviddavid <daviddavid> 3.5.0-1.mga8
+ Revision: 1613567
- new version: 3.5.0

* Fri Feb 21 2020 umeabot <umeabot> 3.4.2-2.mga8
+ Revision: 1547844
- Mageia 8 Mass Rebuild

* Mon Feb 10 2020 daviddavid <daviddavid> 3.4.2-1.mga8
+ Revision: 1488479
- new version: 3.4.2

* Mon Feb 03 2020 daviddavid <daviddavid> 3.4.1-2.mga8
+ Revision: 1486584
- use system Poppler for OMR

* Mon Feb 03 2020 daviddavid <daviddavid> 3.4.1-1.mga8
+ Revision: 1486533
- new version: 3.4.1
- rediff P1, P5 and P6
+ wally <wally>
- build with new cmake macros

* Tue Dec 24 2019 daviddavid <daviddavid> 3.3.4-3.mga8
+ Revision: 1469880
- really update to 3.3.4

* Mon Dec 16 2019 daviddavid <daviddavid> 3.3.4-2.mga8
+ Revision: 1468135
- require QtQuick.Controls version 2

* Thu Dec 05 2019 daviddavid <daviddavid> 3.3.4-1.mga8
+ Revision: 1464393
- new version: 3.3.4

* Thu Nov 28 2019 daviddavid <daviddavid> 3.3.3-1.mga8
+ Revision: 1463365
- new version: 3.3.3

* Thu Nov 14 2019 daviddavid <daviddavid> 3.3.2-1.mga8
+ Revision: 1459986
- new version: 3.3.2

* Thu Nov 14 2019 daviddavid <daviddavid> 3.3.1-1.mga8
+ Revision: 1459929
- new version: 3.3.1

* Thu Nov 07 2019 daviddavid <daviddavid> 3.3.0-2.mga8
+ Revision: 1458676
- fix mscore data dir for "/usr/share/mscore-3.3/"

* Sun Nov 03 2019 daviddavid <daviddavid> 3.3.0-1.mga8
+ Revision: 1457379
- new version: 3.3.0
- rediff fix-revision-number and separate-commonfiles patches

* Thu Jul 11 2019 daviddavid <daviddavid> 3.2.3-1.mga8
+ Revision: 1419979
- new version: 3.2.3
- rediff and rename use-default-soundfont patch

* Tue Jul 02 2019 daviddavid <daviddavid> 3.2.2-1.mga8
+ Revision: 1417594
- new version: 3.2.2
- rename and rediff patches P1 and P6

* Sun Mar 31 2019 umeabot <umeabot> 3.0.5-2.mga7
+ Revision: 1383485
- Qt5 Rebuild

* Thu Mar 14 2019 daviddavid <daviddavid> 3.0.5-1.mga7
+ Revision: 1377055
- new version: 3.0.5
- remove merged upstream remove-trailing-slashes-in-include-lines patch
- rename and rediff revision-number and separate-commonfiles patches

* Wed Mar 06 2019 daviddavid <daviddavid> 3.0.4-1.mga7
+ Revision: 1371902
- new version: 3.0.4

* Wed Feb 27 2019 daviddavid <daviddavid> 3.0.3-1.mga7
+ Revision: 1370369
- new version: 3.0.3

* Mon Feb 25 2019 daviddavid <daviddavid> 3.0.2-3.mga7
+ Revision: 1370176
- enable webengine support thus fixing more Start Center window (mga#24424)

* Mon Feb 25 2019 daviddavid <daviddavid> 3.0.2-2.mga7
+ Revision: 1370100
- fix empty Start Center window (mga#24424)

* Mon Feb 11 2019 daviddavid <daviddavid> 3.0.2-1.mga7
+ Revision: 1365223
- new version: 3.0.2
- rename and rediff some patches
- add two patches to fix build (P6, P7)

* Thu Nov 01 2018 daviddavid <daviddavid> 2.3.2-3.mga7
+ Revision: 1327217
- enable LAME support

* Thu Nov 01 2018 daviddavid <daviddavid> 2.3.2-2.mga7
+ Revision: 1327131
- rebuild for fixed portmidi (now libporttime is available)

* Fri Oct 12 2018 wally <wally> 2.3.2-1.mga7
+ Revision: 1319866
- new version 2.3.2
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun Dec 11 2016 wally <wally> 2.0.3-1.mga6
+ Revision: 1074231
- push to core/release

* Sat Dec 10 2016 wally <wally> 2.0.3-0.3.mga6
+ Revision: 1074162
- require qtquickcontrols5
- drop unneeded requires for qtscriptbindings

* Sat Dec 10 2016 wally <wally> 2.0.3-0.2.mga6
+ Revision: 1074144
- build again with bundled QtSingleApplication

* Sat Dec 10 2016 wally <wally> 2.0.3-0.1.mga6
+ Revision: 1074115
- sync patches with Fedora
+ akien <akien>
- Remove %%post, %%postun and %%posttrans (we have filetriggers)
+ spuhler <spuhler>
- update to vers. 2.0.3
  * new patches from Fedora

* Wed Jan 06 2016 spuhler <spuhler> 2.0.2-6.mga6
+ Revision: 920077
- bumped rel because arm has built
- removed obsolete "BuildRequires:  pkgconfig(Qt5Declarative)"

* Fri Aug 28 2015 spuhler <spuhler> 2.0.2-4.mga6
+ Revision: 870368
- removed "remove-mp3-support.patch"
  * added this to the cmake option

* Fri Jul 24 2015 spuhler <spuhler> 2.0.2-3.mga6
+ Revision: 856966
- more font locations

* Fri Jul 24 2015 spuhler <spuhler> 2.0.2-2.mga6
+ Revision: 856867
- corrected font location in patch

* Thu Jul 23 2015 spuhler <spuhler> 2.0.2-1.mga6
+ Revision: 856601
- added MuseScore-2.0.2-compress_manual_pages.patch
- removed qt5.5 patch
  * has been incorporated in new source
- some spec cleanups
- update to vers. 2.0.2
  * deleted obs. gt-5.5.patch
  * updated patches
- upgrade to vers. 2.0.2
- fixed ldconf non ELF file error message

* Mon Jul 13 2015 spuhler <spuhler> 2.0.1-1.mga6
+ Revision: 853660
- added qt-5.5 patch
- added metainfo.xml file
- more specfile changes
- removed obsolete vers. 1.3 patch  files
- spec file based on Fedora
- first build of 2.0 series (2.0.1)
  * new patches from Fedora

* Wed Oct 15 2014 umeabot <umeabot> 1.3-6.mga5
+ Revision: 741920
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Wed Mar 26 2014 akien <akien> 1.3-4.mga5
+ Revision: 608866
- Add a patch for freetype2 include
- Fix provides for musescore
- Reobsolete musescore with proper version

* Mon Oct 21 2013 spuhler <spuhler> 1.3-3.mga4
+ Revision: 541132
- reversed last change
- changed the make to single cpu to get it built
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ luigiwalser <luigiwalser>
- BR texlive-texmf

* Thu May 23 2013 spuhler <spuhler> 1.3-1.mga4
+ Revision: 424881
- upgrade to version 1.3
- removed none-free prelude sample
- renumbered patches
- removed obsolete fonts line
  * new version will automatically replace/upgrade existing package

* Sun Jan 13 2013 spuhler <spuhler> 1.2-3.mga3
+ Revision: 377983
- changed BuildRequires:  from texlive-mf2pt1 to texlive
  texlive now provides it again
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 11 2012 spuhler <spuhler> 1.2-2.mga3
+ Revision: 317079
- corrected the location of the fonts.
  Theprogram now can find them
  Bumped rel.

* Sun Nov 11 2012 spuhler <spuhler> 1.2-1.mga3
+ Revision: 316904
- changed name of package mscore from musescore to sync with fedora
  replaced the vanilla 1.2 source tar with the one tat has the none free piano fonts removed

